/*
 * manager.c - Routines for oracle ASMLib manager devices.
 *
 * Copyright (c) 2002-2006 Oracle Corporation.  All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License, version 2 as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#define _LARGEFILE_SOURCE
#define _LARGEFILE64_SOURCE     /* For statfs64() */

#include <sys/statfs.h>
#include <errno.h>

#include <linux/types.h>

#ifndef ORACLEASM_OLD_HEADERS
# include "linux/oracleasm/compat32.h"
# include "linux/oracleasm/abi.h"
#else
# include "linux/asmcompat32.h"
# include "linux/asmabi.h"
#endif

#include "manager.h"

int is_manager(const char *filename)
{
    int rc;
    struct statfs64 statfs_buf;

    if (!filename || !*filename)
        return -EINVAL;

    /* I wanted to use statvfs, but there is no f_type */
    rc = statfs64(filename, &statfs_buf);
    if (rc)
        return -errno;

    if (statfs_buf.f_type != ASMFS_MAGIC)
        return -ENXIO;

    return 0;
}  /* is_manager() */


