/*
 * usage.c - Helpers for usage, etc.
 *
 * Copyright (c) 2006 Oracle Corporation.  All rights reserved.
 *
 * The idea and some implementation are ripped off of GIT,
 * Copyright (C) Linus Torvalds, 2005
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License, version 2 as published by the Free Software Foundation.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#define _LARGEFILE_SOURCE
#define _LARGEFILE64_SOURCE

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>

#include "usage.h"

/*
 * A simple error printing routine, it expects the caller to have defined
 * a string "program_name".
 */
void error(const char *err, ...)
{
    va_list params;

    fprintf(stderr, "%s: ", program_name);
    va_start(params, err);
    vfprintf(stderr, err, params);
    va_end(params);
}

/* This expects the caller to have defined a string "program_usage". */
void usage(int rc, const char *err, ...)
{
    FILE *output = rc ? stderr : stdout;
    va_list params;

    if (err) {
        fprintf(stderr, "%s: ", program_name);
        va_start(params, err);
        vfprintf(stderr, err, params);
        va_end(params);
    }

    fprintf(output, "%s", program_usage);
    exit(rc);
}

void version(void)
{
    fprintf(stdout, "%s version %s\n", program_name, VERSION);
    exit(0);
}
